@@ -17,7 +17,7 @@ class LED:
             i = 255
         
         self._pwm.freq(1000)
-        self._pwm.duty_u16(int(256 * i))
+        self._pwm.duty_u16(int(64 * i))
         self._intensity = i
 
     def off(self):
@@ -120,6 +120,9 @@ class Rotary:
     def __init__(self, pin = 28):
         self._adc = ADC(Pin(pin))
         
+    def raw_value(self):
+        return self._adc.read_u16()
+
     def value(self):
         return self._adc.read_u16() / 65536
 
@@ -187,16 +190,16 @@ def test():
         print(what)
         
         while not button.pressed():
-            value = rotary.value()
+            value = rotary.raw_value()
             
             print(value)
             
             if isinstance(what, LED):
-                what.intensity(value)
+                what.intensity(value // 256)
             elif isinstance(what, Servo):
-                what.angle(transform(value, 0, 255, -90, 90))
+                what.angle(transform(value, 0, 65536, -60, 61))
             elif isinstance(what, Speaker):
-                what.tone(transform(value, 0, 255, 10, 10000))
+                what.tone(transform(value, 0, 65536, 10, 10001))
             
             sleep_ms(20)
                        
